@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.8   2013/01/06
+ * Version: 0.1.9   2013/02/14
  */
 
 #ifndef _SECURITY_CAITSITH_INTERNAL_H
@@ -100,6 +100,10 @@
 #define current_fsgid() (current->fsgid)
 #endif
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 9, 0)
+#define f_vfsmnt f_path.mnt
+#endif
+
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 38)
 
 /**
